@@ -62,14 +62,7 @@ class Scraper:
         """
         Returns a list of links
         """
-        links = List(str)
-        for link in self._soup.findAll('a'):
-            print(link)
-            links.append(link['href'])
-        return links
-
-
-
+        return List(str).extend([a.get('href') for a in self._soup.find_all('a')])
 
     def __str__(self):
         return f"""
